@@ -1,24 +1,35 @@
 from IPython.core.magic import Magics, line_magic, magics_class  # type: ignore
-from IPython.core.magic_arguments import (argument, magic_arguments,  # type: ignore
-                                          parse_argstring)  # type: ignore
+from IPython.core.magic_arguments import (
+    argument,
+    magic_arguments,
+    parse_argstring,
+)  # type: ignore
 
 from .main import find_dotenv, load_dotenv
 
 
 @magics_class
 class IPythonDotEnv(Magics):
-
     @magic_arguments()
     @argument(
-        '-o', '--override', action='store_true',
-        help="Indicate to override existing variables"
+        "-o",
+        "--override",
+        action="store_true",
+        help="Indicate to override existing variables",
     )
     @argument(
-        '-v', '--verbose', action='store_true',
-        help="Indicate function calls to be verbose"
+        "-v",
+        "--verbose",
+        action="store_true",
+        help="Indicate function calls to be verbose",
+    )
+    @argument(
+        "dotenv_path",
+        nargs="?",
+        type=str,
+        default=".env",
+        help="Search in increasingly higher folders for the `dotenv_path`",
     )
-    @argument('dotenv_path', nargs='?', type=str, default='.env',
-              help='Search in increasingly higher folders for the `dotenv_path`')
     @line_magic
     def dotenv(self, line):
         args = parse_argstring(self.dotenv, line)
